@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2010, 2011, Sebastian Wiesner <lunaryorn@googlemail.com>
+# Copyright (c) 2010, 2011, 2012, Sebastian Wiesner <lunaryorn@googlemail.com>
 # All rights reserved.
 
 # Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,9 @@
 """
 
 
+from __future__ import (print_function, division, unicode_literals,
+                        absolute_import)
+
 import re
 import posixpath
 
@@ -88,4 +91,4 @@ def resolve_reference_to_epydoc(app, env, node, contnode):
 def setup(app):
     app.require_sphinx('1.0')
     app.add_config_value('epydoc_mapping', {}, 'env')
-    app.connect('missing-reference', resolve_reference_to_epydoc)
+    app.connect(str('missing-reference'), resolve_reference_to_epydoc)
